Chilero's API
=============


chilero.web.application module
------------------------------

.. automodule:: chilero.web.application
    :members:
    :undoc-members:
    :show-inheritance:


chilero.web.resource module
---------------------------

.. automodule:: chilero.web.resource
    :members:
    :undoc-members:
    :show-inheritance:


chilero.web.response module
---------------------------

.. automodule:: chilero.web.response
    :members:
    :undoc-members:
    :show-inheritance:


chilero.web.test module
-----------------------

.. automodule:: chilero.web.test
    :members:
    :undoc-members:
    :show-inheritance:


chilero.web.view module
-----------------------

.. automodule:: chilero.web.view
    :members:
    :undoc-members:
    :show-inheritance:
